FileExt

Trait FileExt 

pub trait FileExt {
    // Required method
    fn filesystem(&self) -> Result<FileSystemKind, Error>;
}
An extension trait for File that allows querying the kind of filesystem it resides on.

Required Methods

fn filesystem(&self) -> Result<FileSystemKind, Error>

Query the filesystem that this file resides on.

Errors

Note that a variant of std::io::Error may be returned, which can indicate a number of error conditions such as corrupted data, insufficient permissions, etc.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FileExt for File

Implementors